Drop output component
This component discards all messages without performing any operations. It’s useful for testing or when you want to intentionally discard data.
Structs
- Drop
Output - Drop output component that discards all messages