Module json

Module json 

Arrow Processor Components

A processor for converting between binary data and the Arrow format

Structs

ArrowToJsonProcessor
JsonToArrowProcessor
Arrow format conversion processor configuration Arrow Format Conversion Processor

Functions

init