Arrow Processor Components
A processor for converting between binary data and the Arrow format
Structs
- Arrow
ToJson Processor - Json
ToArrow Processor - Arrow format conversion processor configuration Arrow Format Conversion Processor